from Products.PluggableAuthService.plugins.ZODBGroupManager import ZODBGroupManager
from zope.component import getMultiAdapter
from Products.CMFCore.utils import getToolByName

def updateGroup(self, group_id, title=None, description=None):
    """
    This one is fixed in Products.PlonePAS 4.x (in plone 4.x)
    @author: mirco
    """
    ZODBGroupManager.updateGroup(self, group_id, title=title, description=description)
    return True

def group_search_results(self):
        """
        Use of our custom function (searchGroups) to search in titles and ids of groups
        @author: mirco
        """
        def search_for_principal(hunter, search_term):
            search_view = getMultiAdapter((hunter, hunter.request), name='adv_search_groups')
            return search_view.searchGroups(search_term)
        
        def get_principal_by_id(group_id):
            portal_groups = getToolByName(self.context, 'portal_groups')
            return portal_groups.getGroupById(group_id)
        
        def get_principal_title(group, _):
            return group.getGroupTitleOrName()
            
        return self._principal_search_results(search_for_principal,
            get_principal_by_id, get_principal_title, 'group', 'groupid')


def main(self):
    """ Update Zope Groups """
    output = ""
    groups = self.portal_groups.listGroups()
    output = output + 'gruppi da analizzare: ' + str(len(groups)) + '\n'
    for group in groups:
        group_data = group.getGroup()
        processed = {}
        processed['title'] = group_data.getProperty('title')
        processed['description'] = group_data.getProperty('description')
        try:
            self.portal_groups.updateGroup(group.id,processed)
            output = output + 'Aggiornato gruppo ' + group.id + ' con i parametri:' + str(processed) + '\n'
        except KeyError:
            output = output + 'ERRORE: Gruppo non presente in Zope: ' +group.id  + '\n'
            pass
    return output


from Products.Five import BrowserView
from zope.component import getMultiAdapter
from Products.PlonePAS.browser.search import PASSearchView

class SearchGroups(BrowserView):
    
    def __init__(self, context, request):
        self.context = context
        self.request = request
        
    def searchGroups(self,searchstring):
        """
        Search in titles and id of groups
        @author: mirco
        """
        if not isinstance(self.context, PASSearchView):
            search_view = getMultiAdapter((self.context, self.request), name='pas_search')
        else:
            search_view = self.context
        groups_by_id = search_view.searchGroups(id=searchstring)
        groups_by_name = search_view.searchGroups(name=searchstring)
        groups_id = {}
        for group in groups_by_id+groups_by_name:
            if group.get('id') not in groups_id.keys():
                groups_id[group.get('id')] = group
        ids = groups_id.keys()
        ids.sort()
        result_groups = []
        for id in ids:
            result_groups.append(groups_id[id])
        return tuple(result_groups)



## Script (Python) "prefs_group_edit"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=addname=None, groupname=None
##title=Edit user
##

from Products.CMFPlone import PloneMessageFactory as _

REQUEST=context.REQUEST
msg = _(u'No changes made.')
group = None

processed={}
for id, property in context.portal_groupdata.propertyItems():
    processed[id]=REQUEST.get(id, None)

if addname:
    success = context.portal_groups.addGroup(addname,(),(),REQUEST=context.REQUEST)
    if not success:
        msg = _(u'Could not add group ${name}, perhaps a user or group with '
                u'this name already exists.', mapping={u'name' : addname})
        context.plone_utils.addPortalMessage(msg, 'error')
        return context.prefs_group_details()
    group=context.portal_groups.getGroupById(addname)
    msg = _(u'Group ${name} has been added.',
            mapping={u'name' : addname})
elif groupname:
    group=context.portal_groups.getGroupById(groupname)
    msg = _(u'Changes saved.')

else:
    msg = _(u'Group name required.')

if group:
    # for what reason ever, the very first group created does not exist
    group.setGroupProperties(processed)
    context.portal_groups.updateGroup(group.id,processed)

context.plone_utils.addPortalMessage(msg, type=group and 'info' or 'error')

target_url = group and context.prefs_groups_overview.absolute_url() or \
                context.prefs_group_details.absolute_url()

return REQUEST.RESPONSE.redirect(target_url)



from Products.PlonePAS.tools.groups import GroupsTool, NotSupported

def updateGroup(self,id,mapping):
    success=0
    managers = self._getGroupManagers()
    if not managers:
        raise NotSupported, 'No plugins allow for group management'
    for mid, manager in managers:
        success = manager.updateGroup(id,
                                      title=mapping.get('title', ''),
                                      description=mapping.get('description', ''))
    return success
        
GroupsTool.updateGroup = updateGroup

from Products.CMFCore.DirectoryView import registerDirectory
from config import SKINS_DIR, GLOBALS

registerDirectory(SKINS_DIR, GLOBALS)

